@@ -26,12 +26,13 @@ class Libpsl(Tarball, Meson):
         Project.__init__(
             self,
             "libpsl",
-            archive_url="https://github.com/rockdaboot/libpsl/releases/download/0.21.1/libpsl-0.21.1.tar.gz",
+            version="0.21.1",
+            archive_url="https://github.com/rockdaboot/libpsl/releases/download/{version}/libpsl-{version}.tar.gz",
             hash="ac6ce1e1fbd4d0254c4ddb9d37f1fa99dec83619c1253328155206b896210d4c",
             dependencies=[
                 "meson",
                 "ninja",
-                "pkg-config",
+                "pkgconf",
                 "icu",
             ],
         )
