@@ -26,7 +26,9 @@ class Librsvg(Tarball, Project):
         Project.__init__(
             self,
             "librsvg",
-            archive_url="https://download.gnome.org/sources/librsvg/2.54/librsvg-2.54.5.tar.xz",
+            version="2.54.5",
+            repository="https://gitlab.gnome.org/GNOME/librsvg",
+            archive_url="https://download.gnome.org/sources/librsvg/{major}.{minor}/librsvg-{version}.tar.xz",
             hash="4f03190f45324d1fa1f52a79dfcded1f64eaf49b3ae2f88eedab0c07617cae6e",
             dependencies=[
                 "cargo",
