@@ -25,8 +25,9 @@ class Lz4(Tarball, Project):
         Project.__init__(
             self,
             "lz4",
-            archive_url="https://github.com/lz4/lz4/archive/v1.9.4.tar.gz",
-            archive_file_name="lz4-1.9.4.tar.gz",
+            version="1.9.4",
+            archive_url="https://github.com/lz4/lz4/archive/v{version}.tar.gz",
+            archive_file_name="lz4-{version}.tar.gz",
             hash="0b0e3aa07c8c063ddf40b082bdf7e37a1562bda40a0ff5272957f3e987e0e54b",
         )
 
